@@ -485,7 +485,7 @@ carto.Parser = function Parser(env) {
 
                     if (! $(')')) return;
 
-                    if (name) { return new tree.Call(name, args) }
+                    if (name) { return new tree.Call(name, args, i) }
                 },
                 arguments: function() {
                     var args = [], arg;
